## justlog ##

[Documentation](https://justlog.readthedocs.io/en/latest/)

justlog is a simple library for Python 3. It is designed to provide a quick and easy way to generate clean logs with minimal coding.

### Features ###

- Output to to stdout, stderr, tcp, http, file or syslog
- Output in standard text or json
- Easily add fields
- Builtin variables for timestamps and log levels.
- Colorful output

### Quickstart ###

https://justlog.readthedocs.io/en/latest/#quickstart

### Installation ###

```python
pip install justlog
```

### License ###

- MIT
